==> symbol-processing-aa-embeddable-2.1.0-1.0.29-sources.jar: org/jetbrains/kotlin/analysis/api/fir/symbols/KaFirFileSymbol.kt <==
/*
 * Copyright 2010-2024 JetBrains s.r.o. and Kotlin Programming Language contributors.
 * Use of this source code is governed by the Apache 2.0 license that can be found in the license/LICENSE.txt file.
 */

package ksp.org.jetbrains.kotlin.analysis.api.fir.symbols

import ksp.com.intellij.psi.PsiElement
import ksp.org.jetbrains.kotlin.analysis.api.annotations.KaAnnotationList
import ksp.org.jetbrains.kotlin.analysis.api.fir.KaFirSession
import ksp.org.jetbrains.kotlin.analysis.api.lifetime.withValidityAssertion
import ksp.org.jetbrains.kotlin.analysis.api.symbols.KaFileSymbol
import ksp.org.jetbrains.kotlin.analysis.api.symbols.pointers.KaSymbolPointer
import ksp.org.jetbrains.kotlin.analysis.low.level.api.fir.api.getOrBuildFirFile
import ksp.org.jetbrains.kotlin.asJava.classes.lazyPub
import ksp.org.jetbrains.kotlin.fir.psi
import ksp.org.jetbrains.kotlin.fir.symbols.impl.FirFileSymbol
import ksp.org.jetbrains.kotlin.psi.KtFile

internal class KaFirFileSymbol private constructor(
    override val backingPsi: KtFile?,
    override val lazyFirSymbol: Lazy<FirFileSymbol>,
    override val analysisSession: KaFirSession,
) : KaFileSymbol(), KaFirKtBasedSymbol<KtFile, FirFileSymbol> {
    constructor(file: KtFile, session: KaFirSession) : this(
        backingPsi = file,
        lazyFirSymbol = lazyPub {
            file.getOrBuildFirFile(session.firResolveSession).symbol
        },
        analysisSession = session,
    )

    constructor(symbol: FirFileSymbol, session: KaFirSession) : this(
        backingPsi = symbol.fir.psi as? KtFile,
        lazyFirSymbol = lazyOf(symbol),
        analysisSession = session,
    )

    override val psi: PsiElement? get() = withValidityAssertion { backingPsi }

    override fun createPointer(): KaSymbolPointer<KaFileSymbol> = withValidityAssertion {
        psiBasedSymbolPointerOfTypeIfSource()
            ?: TODO("Creating pointers for not PSI-backed files or files from a library is not supported yet")
    }

    override val annotations: KaAnnotationList
        get() = withValidityAssertion {
            psiOrSymbolAnnotationList()
        }

    override fun equals(other: Any?): Boolean = psiOrSymbolEquals(other)
    override fun hashCode(): Int = psiOrSymbolHashCode()
}

==> symbol-processing-aa-embeddable-2.3.4-sources.jar: org/jetbrains/kotlin/analysis/api/fir/symbols/KaFirFileSymbol.kt <==
/*
 * Copyright 2010-2024 JetBrains s.r.o. and Kotlin Programming Language contributors.
 * Use of this source code is governed by the Apache 2.0 license that can be found in the license/LICENSE.txt file.
 */

package ksp.org.jetbrains.kotlin.analysis.api.fir.symbols

import ksp.com.intellij.psi.PsiElement
import ksp.org.jetbrains.kotlin.analysis.api.annotations.KaAnnotationList
import ksp.org.jetbrains.kotlin.analysis.api.fir.KaFirSession
import ksp.org.jetbrains.kotlin.analysis.api.lifetime.withValidityAssertion
import ksp.org.jetbrains.kotlin.analysis.api.symbols.KaFileSymbol
import ksp.org.jetbrains.kotlin.analysis.api.symbols.pointers.KaSymbolPointer
import ksp.org.jetbrains.kotlin.analysis.low.level.api.fir.api.getOrBuildFirFile
import ksp.org.jetbrains.kotlin.asJava.classes.lazyPub
import ksp.org.jetbrains.kotlin.fir.psi
import ksp.org.jetbrains.kotlin.fir.symbols.impl.FirFileSymbol
import ksp.org.jetbrains.kotlin.psi.KtFile

internal class KaFirFileSymbol private constructor(
    override val backingPsi: KtFile?,
    override val lazyFirSymbol: Lazy<FirFileSymbol>,
    override val analysisSession: KaFirSession,
) : KaFileSymbol(), KaFirKtBasedSymbol<KtFile, FirFileSymbol> {
    constructor(file: KtFile, session: KaFirSession) : this(
        backingPsi = file,
        lazyFirSymbol = lazyPub {
            file.getOrBuildFirFile(session.resolutionFacade).symbol
        },
        analysisSession = session,
    )

    constructor(symbol: FirFileSymbol, session: KaFirSession) : this(
        backingPsi = symbol.fir.psi as? KtFile,
        lazyFirSymbol = lazyOf(symbol),
        analysisSession = session,
    )

    override val psi: PsiElement? get() = withValidityAssertion { backingPsi }

    override fun createPointer(): KaSymbolPointer<KaFileSymbol> = withValidityAssertion {
        psiBasedSymbolPointerOfTypeIfSource()
            ?: TODO("Creating pointers for not PSI-backed files or files from a library is not supported yet")
    }

    override val annotations: KaAnnotationList
        get() = withValidityAssertion {
            psiOrSymbolAnnotationList()
        }

    override fun equals(other: Any?): Boolean = psiOrSymbolEquals(other)
    override fun hashCode(): Int = psiOrSymbolHashCode()
}
